==> universal-indent-gui-tqt-trinity-14.1.3.tar.xz: universal-indent-gui-tqt-trinity-14.1.3/src/AboutDialog.cpp <==
/***************************************************************************
 *   Copyright (C) 2006-2012 by Thomas Schweitzer                          *
 *   thomas-schweitzer(at)arcor.de                                         *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License version 2.0 as   *
 *   published by the Free Software Foundation.                            *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program in the file LICENSE.GPL; if not, write to the *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#include "config.h"
#include "AboutDialog.h"

//----#include <tqlocale.h>
#include <tqlabel.h>
#include <tqpushbutton.h>
#include <tqfont.h>


// Displays a dialog window with information about UniversalIndentGUI
AboutDialog::AboutDialog(TQWidget *parent, WFlags flags) :
		AboutDialogBase(parent, NULL, FALSE, flags)
{
	TQFont titleFont = titleLabel->font();
	titleFont.setPointSize(20);
	titleLabel->setFont(titleFont);

	connect(okButton, TQ_SIGNAL(clicked()), this, TQ_SLOT(accept()));
}

// Catches language change events and retranslates all needed widgets.
void AboutDialog::changeEvent(TQEvent *event)
{
//----	if (event->type() == TQEvent::LanguageChange)
//----	{
//----		_dialogForm->retranslateUi(this);
//----
//----		TQString versionString = _dialogForm->versionTextBrowser->toHtml();
//----		versionString =
//----		        versionString.arg(PROGRAM_VERSION_STRING);
//----		_dialogForm->versionTextBrowser->setHtml(versionString);
//----	}
//----	else
//----	{
//----		TQWidget::changeEvent(event);
//----	}
}

#include "AboutDialog.moc"

==> universal-indent-gui-tqt-trinity-14.1.5.tar.xz: universal-indent-gui-tqt-trinity-14.1.5/src/AboutDialog.cpp <==
/***************************************************************************
 *   Copyright (C) 2006-2012 by Thomas Schweitzer                          *
 *   thomas-schweitzer(at)arcor.de                                         *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License version 2.0 as   *
 *   published by the Free Software Foundation.                            *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program in the file LICENSE.GPL; if not, write to the *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#include "config.h"
#include "AboutDialog.h"

//----#include <tqlocale.h>
#include <tqlabel.h>
#include <tqpushbutton.h>
#include <tqfont.h>


// Displays a dialog window with information about UniversalIndentGUI
AboutDialog::AboutDialog(TQWidget *parent, WFlags flags) :
		AboutDialogBase(parent, NULL, false, flags)
{
	TQFont titleFont = titleLabel->font();
	titleFont.setPointSize(20);
	titleLabel->setFont(titleFont);

	connect(okButton, TQ_SIGNAL(clicked()), this, TQ_SLOT(accept()));
}

// Catches language change events and retranslates all needed widgets.
void AboutDialog::changeEvent(TQEvent *event)
{
//----	if (event->type() == TQEvent::LanguageChange)
//----	{
//----		_dialogForm->retranslateUi(this);
//----
//----		TQString versionString = _dialogForm->versionTextBrowser->toHtml();
//----		versionString =
//----		        versionString.arg(PROGRAM_VERSION_STRING);
//----		_dialogForm->versionTextBrowser->setHtml(versionString);
//----	}
//----	else
//----	{
//----		TQWidget::changeEvent(event);
//----	}
}

#include "AboutDialog.moc"
